﻿using System;
using System.Collections.Generic;
using System.Drawing;
using System.Windows.Forms;

using Infragistics.Win;
using Infragistics.Win.UltraWinGrid;
using Infragistics.Win.UltraWinScrollBar;

namespace GridControl
{
    /// <summary>
    /// Represents a helper class for third party controls and the user interface.
    /// </summary>
    internal static class UiHelper
    {
        #region UltraGrid
        public static void InitializeGridSettings(UltraGrid grid)
        {
            grid.DisplayLayout.GroupByBox.Hidden = true;
            grid.DisplayLayout.AutoFitStyle = AutoFitStyle.ResizeAllColumns;

            grid.DisplayLayout.Override.AllowColMoving = AllowColMoving.NotAllowed;
            grid.DisplayLayout.Override.AllowUpdate = DefaultableBoolean.False;
            grid.DisplayLayout.Override.AllowDelete = DefaultableBoolean.False;
            grid.DisplayLayout.Override.SelectTypeRow = Infragistics.Win.UltraWinGrid.SelectType.Extended;
            grid.DisplayLayout.Override.CellClickAction = Infragistics.Win.UltraWinGrid.CellClickAction.RowSelect;
            grid.DisplayLayout.Override.RowSelectors = DefaultableBoolean.False;

            // Turn off the vertical lines
            grid.DisplayLayout.Override.BorderStyleCell = UIElementBorderStyle.None;

            grid.DisplayLayout.Override.HeaderAppearance.BackColor = Color.FromArgb(226, 238, 253);
            grid.DisplayLayout.Override.HeaderAppearance.BackColor2 = Color.FromArgb(175, 210, 255);
            grid.DisplayLayout.Override.HeaderAppearance.BackGradientStyle = GradientStyle.GlassTop50;
            grid.DisplayLayout.Override.CellAppearance.TextTrimming = TextTrimming.EllipsisCharacter;
        }

        /// <summary>
        /// Sets the attributes for an image column.
        /// </summary>
        /// <param name="column">The column whose attributes are being initialized.</param>
        /// <param name="width">The width of the column.</param>
        /// <param name="headerImage">The image to be displayed in the header.</param>
        public static void SetColumnAttributes(UltraGridColumn column, int width, Bitmap headerImage)
        {
            column.Width = width;
            column.MinWidth = width;
            column.MaxWidth = width;
            column.LockedWidth = true;
            column.DataType = typeof (Image);
            column.Header.Appearance.Image = headerImage;
            column.Header.Caption = string.Empty;
            column.CellAppearance.ImageHAlign = HAlign.Center;
        }

        /// <summary>
        /// Sets the attributes for non-image columns.
        /// </summary>
        /// <param name="column">The column whose attributes are being initialized.</param>
        /// <param name="width">The width of the column.</param>
        /// <param name="textHAlign">The alignment of text horizontally.</param>
        public static void SetColumnAttributes(UltraGridColumn column, int width, HAlign textHAlign, string caption)
        {
            column.Width = width;
            column.CellAppearance.TextHAlign = textHAlign;
            column.Header.Caption = caption;
        }

        #endregion
    }
}
